<?php
//=================================================================	
// TNETWeather WDSparkline Graph Script
//=================================================================	
// Common.php
// 
// Library provides Weather Math and other functions used by this
// system.
//=================================================================
global $SITE, $DEBUG;

//

############################################################################
# Converts degC to degF with precision
############################################################################

function tempToF ($cTemp, $prec=0)
{
	if (!isset($cTemp)) {
		return false;
	}
	$prec = (integer)$prec;
	$fTemp = (float)(1.8 * $cTemp) + 32;
	return round($fTemp, $prec);
}


############################################################################
# Converts mm to Inches for Rain with precision
############################################################################

function cmToInch ($cm, $prec)
{
	if (!isset($cm)) {
		return false;
	}
	$prec = (integer)$prec;
	$inch = (float)$cm / 25.4;
	return round($inch, $prec);
}

############################################################################
# Converts Knots to MPH with precision
############################################################################

function ktsToMph ($kts, $prec)
{
  if (!isset($kts)) {
    return false;
  }
  $prec = (integer)$prec;
  $inch = (float)$kts * 1.15078;
  return round($inch, $prec);
}

############################################################################
# Converts Millibars to Inches of Mercury InHg
############################################################################

function mbToInHg32 ($mbar, $prec)
{
	if (!isset($mbar)) {
		return false;
	}
	$prec = (integer)$prec;
	$inch = (float)$mbar * 0.02953;
	return round($inch, $prec);
}

############################################################################
# Converts Millibars to Kilopascals kPa
############################################################################
function mbTokPa ($mbar, $prec)
{
	if (!isset($mbar)) {
		return false;
	}
	$prec = (integer)$prec;
	$inch = (float)$mbar * 0.10;
	return round($inch, $prec);
}

############################################################################
# Converts Feet to Meters with precision
############################################################################

function feetToMeters ($feet, $prec)
{
  if (!isset($feet)) {
    return false;
  }
  $prec = (integer)$prec;
  $meters = (float)$feet * 0.3048;
  return round($meters, $prec);
}

############################################################################
# Converts Knots to m/s with precision
############################################################################

function ktsToMsec ($kts, $prec)
{
  if (!isset($kts)) {
    return false;
  }
  $prec = (integer)$prec;
  $inch = (float)$kts * 0.514444;
  return round($inch, $prec);
}

############################################################################
# Converts Knots to km/h with precision
############################################################################

function ktsToKmh ($kts, $prec) {
	if (!isset($kts)) {
		return false;
	}
	$prec = (integer)$prec;
	$inch = (float)$kts * 1.852;
	return round($inch, $prec);
}

############################################################################
# Returns 16 point Letters of Dir from Degree's
############################################################################

function windDir ($winddir)
{
	if (!isset($winddir)) {
		return "---";
	}
	$windlabel = array ("N","NNE", "NE", "ENE", "E", "ESE", "SE", "SSE", "S",
		"SSW","SW", "WSW", "W", "WNN", "NW", "NNW");
	$dir = $windlabel[ fmod((($winddir + 11) / 22.5),16) ];
	return "$dir";
}

############################################################################
# Function - Converts Degrees / Minutes /Seconds to
# Decimal Formatted Longitude / Latitude
############################################################################

function DMStoDEC($deg,$min,$sec) {
    return $deg+((($min*60)+($sec))/3600);
}    

############################################################################
# Function - Converts Decimal Formatted Longitude / Latitude
# to DMS ( Degrees / Minutes / Seconds )
############################################################################

function DECtoDMS($dec) {
	$vars = explode(".",$dec);
	$deg = $vars[0];
	$tempma = "0.".$vars[1];

	$tempma = $tempma * 3600;
	$min = floor($tempma / 60);
	$sec = $tempma - ($min*60);

	return array("deg"=>$deg,"min"=>$min,"sec"=>$sec);
}   

############################################################################
############################################################################
# NON WEATHER FUNCTIONS
############################################################################
############################################################################

############################################################################
# DaysInMonth - Returns how many days are in a month for a specific Year
############################################################################

function DaysInMonth ( $Year, $MonthInYear )
{
	if ( in_array ( $MonthInYear, array ( 1, 3, 5, 7, 8, 10, 12 ) ) )
		return 31;

	if ( in_array ( $MonthInYear, array ( 4, 6, 9, 11 ) ) )
		return 30;

	if ( $MonthInYear == 2 )
		return ( checkdate ( 2, 29, $Year ) ) ? 29 : 28;
		
	return false;
}

############################################################################
# Functions to Convert to Uppercase Sentences
# TNET Services, Inc.
############################################################################

function ucfsentence($ctxt) {
        $ctxt = strtolower($ctxt);
        $ctxt = sentence_cap(". ",$ctxt);
        $ctxt = sentence_cap("! ",$ctxt);
        $ctxt = sentence_cap("? ",$ctxt);
        return($ctxt);
}

function sentence_cap($impexp, $sentence_split) {
    $textbad=explode($impexp, $sentence_split);
    $newtext = array();
    foreach ($textbad as $sentence) {
        $sentencegood=ucfirst($sentence);
        $newtext[] = $sentencegood;
    }
    $textgood = implode($impexp, $newtext);
    return $textgood;
}

############################################################################
# Function determines if a network in the form of 192.168.17.1/16 or
# 127.0.0.1/255.255.255.255 or 10.0.0.1 matches a given IP
# TNET Services, Inc.
############################################################################

function net_match($network, $ip) {
	$ip_arr = explode('/', $network);
	$network_long = ip2long($ip_arr[0]);

	$x = ip2long($ip_arr[1]);
	$mask =  long2ip($x) == $ip_arr[1] ? $x : 0xffffffff << (32 - $ip_arr[1]);
	$ip_long = ip2long($ip);

	dbmsg("Net_Match >".$ip_arr[1]."> ".decbin($mask));
	return ($ip_long & $mask) == ($network_long & $mask);
}

############################################################################
# Functin LogFile
# Outputs a Message ($msg) to a Logfile ($logfile) with a current ISO
# formatted timestamp that is sortable.  Messages end with a NewLine
# WARNING: Logfile needs to have permissions to be written to by a web
# process or it will fail.  ASSUMES TZ Already set by system.
# TNET Services, Inc.
############################################################################

function LogFile ($logfile, $msg) {
	global $SITE;
	
	if (!isset($logfile)) return false;

	$TheTime = date("Y/m/d h:i:s");
	$sendmsg = $TheTime . " - " . $msg . "\n";
	if (!$handle = fopen($logfile, "a+")) {
		die("Failed to open log file");
	}
	if (fwrite($handle, $sendmsg ) === FALSE) {
		die("Failed to write to log file");
	}
	fclose($handle);
	return(true);
}


############################################################################
# Function: output_gfx_error
#
# Function outputs an error box in PNG format that
# conveys a reason why the expected opperation did
# not work.
#
# It accepts three arguments
#
# $errono	= An error number
# $error1	= First Line of Error
# $error2	= Second Line of Error
#
# TNET Services, Inc.
############################################################################

function output_gfx_error ( $errono, $error1, $error2 ) {
	global $SITE;
	
	$imgWidth = 200;
	$imgHeight = 40;

	// Create An Image plate

	$i = ImageCreate($imgWidth,$imgHeight);

	// Allocate Colors
	$bg = imagecolorallocate ($i, 0xFF, 0x00, 0x00);
	$fg = imagecolorallocate ($i, 0xFF, 0xFF, 0xFF);
	$sc = imagecolorallocate ($i, 0xFF, 0xFF, 0x00);
	//$sb = imagecolorallocate ($i, 0x00, 0x00, 0x00);	

	// Generate Error Text
	imagestring ($i, 3, 5, 0,  "WDS " . $SITE['WDSversion'] . " ERROR MSG " . $errono, $sc);
	imagestring ($i, 2, 5, 12, $error1, $sc);
	imagestring ($i, 2, 5, 24, $error2, $sc);

	// Output Header so Browser knows what is comming
	// Followed by the Image then Destroy the image
	header("Content-type: image/png");
	ImagePNG($i);
	ImageDestroy($i);
	
	// Say goodbye...
	exit;
}



############################################################################
############################################################################