<?php
//=================================================================	
// TNETWeather WDSparkline Graph Script
//=================================================================	
// Originally based upon a script provided by "Pinto"
// http://www.joske-online.be/
//
// Modified into a single PHP script utility by:
//   Kevin Reed (KrelvinAZ)
//	http://www.TNETWeather.com - weather@tnetweather.com
//
// FULL CREDITS FOR WHO HAS CONTRIBUTED TO THIS SCRIPT CAN
// BE FOUND IN THE PDF MANUAL.  THIS HAS BEEN A WORLD WIDE
// CONTRIBUTED DEVELOPMENT PROJECT
//
// Please see PDF documentation for full list of contributors
//
//=================================================================	
// This script uses the SparkLine PHP Graphing Library:
// Sparkline PHP Graphing Library
// Copyright 2004 James Byers <jbyers@users.sf.net>
// http://sparkline.org
// 
// Sparkline is distributed under a BSD License. 
// See LICENSE for details.
//=================================================================	
//
// PLEASE READ DOCUMENTATION PDF FOR FULL INFO.
// Basic info provided in README file in package directory
//
//=================================================================
//  TNET WebGen Scripts - (Normally Commented out)
//=================================================================	
//require_once("../Settings.php");
//require_once("../Weather-math.php");
//require_once("../Clientraw.php");
//=================================================================	
$SITE = array();
$SITE['WDSversion']			= "1.0.5";
$SITE['WDSUserAgent']		= "WDSparkline " . $SITE['WDSversion'];
$DEBUG						= 0;	
###################################################################	
#  CONFIGURATION SETTINGS STUFF IS BELOW
###################################################################
// LOCATION OF SPARKLINE LIBRARIES (Normally don't need to change)
$WDSchart_sparklib			= 'lib/Sparkline_Line.php';
//=================================================================
// LOCATION OF WD CLIENTRAW FILES
// Script needs to know what directory your WD Clientraw scripts
// are located in.  Normally this setting will be correct.
// See documentation for more details
$SITE['hloc'] 				= "../";
//=================================================================
// VALID CHART TYPES (Note First Entry is Default)
$WDSvalid_chart_types		= array("temp","rain","winds",
								"windg","hum","baro");
//=================================================================
// VALID CHART UNIT TYPES (Note First entry is default)
$WDScharts = array (     
//  Chart        Valid Units - First is Default
//    -------        ------------------------------
    "temp"    =>    array("fdeg","cdeg"),
    "rain"    =>    array("in","mm"),
    "baro"    =>    array("inhg","mb","kpa"),
    "winds"    =>    array("mph","kts","kmh","ms"),
    "windg" =>    array("mph","kts","mph","kmh","ms"),
    "hum"    =>    array("per") );
//=================================================================
// Allow or Disallow Remote Mode (get data from another site)
// There are three settings:  OFF  ON  CLI
$WDSremote_allow			= 'ON';
//=================================================================
// DEFAULT COLOR SETTINGS (Used by all charts)
// If you want each chart to have their own color schemes
// You will need to go down in the source code below to change
// them. Look for - Set Values for various Charts
// 
// The only predefined Colors you can use BY NAME are:
//   aqua		#00FFFF
//   black		#010101 (Known Sparkline lib issue)
//   blue		#0000FF
//   fuscia		#FF00FF
//   gray		#808080
//   green		#008000
//   lime		#00FF00
//   maroon		#800000
//   navy		#000080
//   olive		#808000
//   purple		#800080
//   red		#FF0000
//   silver		#C0C0C0
//   teal		#008080
//   white		#FFFFFF
//   yellow		#FFFF00
//
// Warning: Only the above COLOR NAMES allowed
$WDSdefault_text_color 		= 'green';
$WDSdefault_line_color 		= 'green';
$WDSdefault_min_color 		= 'blue';
$WDSdefault_max_color 		= 'red';
// Warning: Hex Values are only supported for the chart background
$WDSdefault_backgnd_color 	= '#FFFFFF';
//=================================================================
// LANGUAGE SETTINGS
// Languages are stored in the WDSLanguage.php file but are
// described here.  The first entry is considered the DEFAULT and
// is used anytime you don't specifically use the lang option.
//
// To change the default, make the first entry the language
// you want it to be.  WDS Comes with ENGLISH as the default.
$WDSLanguages = array (
	"ENGLISH",	// Default
	"DANISH","FRENCH","ITALIAN","DUTCH","SPANISH","SWEDISH");
	
###################################################################
#  END OF NORMAL CONFIGURATION CHANGES
###################################################################

//=================================================================
// ADDITIONAL LIBRARIES WILL USE FOR THIS SCRIPT
//=================================================================
// Check for existence of required GD PHP Library
if( ! function_exists("gd_info")){
  die("Sorry.. this script requires the GD library in PHP to function.");
}
// Load Libraries Used by Script
require_once( "Common.php");
require_once( "Clientraw.php");
require_once( "WDSlanguage.php");
require_once( "$WDSchart_sparklib" );
//=================================================================	
//	DETERMINE WHICH MODE WE ARE IN - WEB OR CLI
//=================================================================		
if ( php_sapi_name() == "cli" ) {
	$mode="CLI"; $DEBUGLM = 0;
} else {
	$mode="WEB"; $DEBUGLM = 1;
}
//=================================================================	
//	WEB MODE - Default
//=================================================================	
if ($mode == "WEB") {

	// Check to see if Debug Mode Should be on
	if ( isset( $_GET['debug'] ) ) {
		$DEBUG = 1;
		dbmsg ("DEBUG MODE ON");
	}

	// Display Remote Access Permission in CFG
	dbmsg("Remote Access Permission is set to [" . 
		$WDSremote_allow . "]");
				
	// Check for Chart Request Type
	if ( isset( $_GET['chart']  ) ) {
		$chart_type = strtolower( $_GET['chart'] );
		dbmsg("Found Chart Type Request of [" . $chart_type . "]");		
	}
		
	// Check for Unit Designation
	
	if ( isset( $_GET['unit'] ) ) {
		$chart_unit = strtolower( $_GET['unit'] );
		dbmsg("Found Chart Lang Request of [" . $chart_unit . "]");
	}
				
	// Check for Remote Site Request
	
	// Updated: cleaner code from Ken True.
	if ( isset( $_GET['remote'] ) ) {
		if ( $WDSremote_allow == "OFF" || $WDSremote_allow == "CLI"){
			if ($DEBUG) {
				dbmsg("Remote Access Denied by configuration. <b>FATAL ERROR</b>");
				exit;
			} else {
				// Fatal Error
				output_gfx_error ( "#001", "Remote Option Failed", "Remote Access Denied by CFG" );
				exit;
			}
		}
		
		$REMOTE_PARTS = parse_url( $_GET['remote'] );
		$REMOTE_CHART = 'http://' . $REMOTE_PARTS['hostname'];
		if (! empty($REMOTE_PARTS['path']) ) {
			$REMOTE_CHART .= $REMOTE_PARTS['path'];
		}
		$REMOTE_CHART .= '/clientrawhour.txt';
		dbmsg("Found Remote Request of [" . $REMOTE_CHART . "]");
	}

	// Check for Lang Designation
	
	if ( isset( $_GET['lang'] ) ) {
		$chart_lang = strtoupper( $_GET['lang'] );
		dbmsg("Found Chart Unit Request of [" . $chart_lang . "]");
	}
	
	//##############################################################
	//END OF OPTION CHECKS START OF VERIFICATION OF WHAT WE GOT
	//##############################################################

	// First lest get an array of the chart keys...
	$chart_keys = array_keys($WDScharts);

	dbmsg("Checking for Chart Request");
	
	// Check for Chart Designation
	if ( empty($chart_type) ){
		dbmsg("No Chart Requested, Setting DEFAULT of [" . 
				$chart_keys[0] ."]");
		$chart_type = $chart_keys[0];
	} else {
		dbmsg("Check found there was a valid chart type");
	}
	
	dbmsg("Checking for Valid Chart Type");

	$cval = in_array( $chart_type , $chart_keys );
	
	if ( !$cval ) {
		if ($DEBUG) {
			dbmsg("Invalid Chart Type Specified [" .
				$chart_type . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#002", "Invalid Chart Type", $chart_type . " is not valid" );
			exit;
		}
	} else {
		dbmsg("Valid Chart Type Found");
	}	
	
	// Do we have a chart unit selected?
	
	dbmsg("Checking for any Chart Unit Selected");
	
	if ( empty($chart_unit) ) {
		$chart_unit = $WDScharts[$chart_type][0];
		dbmsg("No Chart Unit Specified using default [" .
				$chart_unit . "]");
	} else {
		dbmsg("A Chart Unit was Selected");	
	}		
	
	// Now Check to make sure that Chart Unit is a valid one
	$cval = in_array( $chart_unit , $WDScharts[$chart_type], true);
	
	if ( ! $cval ) {
		if ($DEBUG) {
			dbmsg("ERROR #003 - Invalid Chart Unit Specified [" .
				$chart_unit . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#003", "Invalid Chart Unit", "'" . 
				$chart_unit . "' is not valid" );
			exit;
		}
	} 
	dbmsg("A valid Chart Unit for Chart Type was found");
	
	$cval = in_array( $chart_unit , $WDScharts[$chart_type], true);
	
	if ( ! $cval ) {
		if ($DEBUG) {
			dbmsg("ERROR #003 - Invalid Chart Unit Specified [" .
				$chart_unit . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#003", "Invalid Chart Unit", "'" . 
				$chart_unit . "' is not valid" );
			exit;
		}
	} 
	
	// Now Check to make sure that Chart Lang is a valid one
	
	if ( empty($chart_lang) ){
		$chart_lang = $WDSLanguages[0];
		dbmsg("No Language selected, using default [" .
			$chart_lang . "]");
	}
	
	dbmsg("Checking for valid Language Setting");
	
	$lval = in_array( $chart_lang , $WDSLanguages, true);	
	
	if ( ! $lval ) {
		if ($DEBUG) {
			dbmsg("ERROR #006 - Invalid Lang Specified [" .
				$chart_lang . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#006", "Invalid Lang Specified", "'" . 
				$chart_lang . "' is not valid" );
			exit;
		}
	} 
	
	$SITE['WDSlanguage'] = $chart_lang;		
	dbmsg("Setting Lang Global to [" . $SITE['WDSlanguage'] .
		"]");
	
	dbmsg("<b>SUCCESSFULLY COMPLETED CHART and UNITS SELECTION</b>");
		
	// Okay... we got through the selection of the chart and unit and if there
	// is a remote requested, we have that too.  So we now need to get
	// the data from file or Network...

	// get chart data
	if ( empty($REMOTE_CHART) ) {
		dbmsg("REMOTE Not Set, Get Local File");
		$SITE['wdclienthour']	= get_raw($SITE['hloc'] . 
			'clientrawhour.txt',' ', 1);
	} else {
		dbmsg("REMOTE SET, Get Network Copy of File");
		$SITE['wdclienthour']	= get_raw( $REMOTE_CHART,' ', 0 );
	}

	// Unless we got an error... we are done with WEB MODE
	// =======================================================================

} else {
	
//=================================================================	
//	CLI MODE
//=================================================================		

	$passed = array();
	
	for( $i = 1; $i < $argc ; $i ++ ) {
		$passed[] = $argv[$i];
	}
	
	foreach ( $passed as $value) {

		// Check for Debug
		if ( strtolower($value) == "debug" ) {
			$DEBUG = 1;
			dbmsg("DEBUG MODE ON");
		}
		
		// Check for = arguments
		if ( strstr($value, "=" ) ) {
	
			list($code,$val) = explode("=",$value);
			
			if (strtolower($code) == "chart" ){
				$chart_type = strtolower($val);
				dbmsg("Found Chart Type Request of [" . 
						$chart_type . "]");
			}
			
			if (strtolower($code) == "unit" ){
				$chart_unit = strtolower($val);
				dbmsg("Found Chart Unit Request of [" . 
						$chart_type . "]");
			}				
			
			// Updated: cleaner code from Ken True.
			if (strtolower($code) == "remote" ) {
				if ( $WDSremote_allow == "OFF" ){
					if ($DEBUG) {
						dbmsg("ERROR #001 - Remote Access Denied by configuration. <b>FATAL ERROR</b>");
						exit;
					} else {
						// Fatal Error
						output_gfx_error ( "#001", "Remote Option Failed", 
							"Remote Access Denied by CFG" );
						exit;
					}
				}

				$REMOTE_PARTS = parse_url( strtolower($val) );
				$REMOTE_CHART = 'http://' . $REMOTE_PARTS['hostname'];
				if (! empty($REMOTE_PARTS['path']) ) {
					$REMOTE_CHART .= $REMOTE_PARTS['path'];
				}
				$REMOTE_CHART .= '/clientrawhour.txt';
				dbmsg("Found Remote Request of [" . $REMOTE_CHART . "]");
			}
			
			// Check for Unit Designation
	
			if ( strtolower($code) == "lang" ) {
				$chart_lang = strtoupper($val);
				dbmsg("Found Chart Lang Request of [" . $chart_lang . "]");
			}			
		}
	}
	
	//##############################################################
	//END OF OPTION CHECKS START OF VERIFICATION OF WHAT WE GOT
	//##############################################################	
	
	//=====================================================
	// DUPLICATED CODE SEGMENT - FUNCTIONIZE IT WHEN WE
	// GET A CHANCE TO.
	//=====================================================
		
	// First lest get an array of the chart keys...
	$chart_keys = array_keys($WDScharts);

	dbmsg("Checking for Chart Request");
	
	// Check for Chart Designation
	if ( empty($chart_type) ){
		dbmsg("No Chart Requested, Setting DEFAULT of [" . 
				$chart_keys[0] ."]");
		$chart_type = $chart_keys[0];
	} else {
		dbmsg("Check found there was a valid chart type");
	}
	
	dbmsg("Checking for Valid Chart Type");

	$cval = in_array( $chart_type , $chart_keys );
	
	if ( !$cval ) {
		if ($DEBUG) {
			dbmsg("Invalid Chart Type Specified [" .
				$chart_type . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#002", "Invalid Chart Type", $chart_type . " is not valid" );
			exit;
		}
	} else {
		dbmsg("Valid Chart Type Found");
	}	
	
	// Do we have a chart unit selected?
	
	dbmsg("Checking for any Chart Unit Selected");
	
	if ( empty($chart_unit) ) {
		$chart_unit = $WDScharts[$chart_type][0];
		dbmsg("No Chart Unit Specified using default [" .
				$chart_unit . "]");
	} else {
		dbmsg("A Chart Unit was Selected");	
	}		
	
	// Now Check to make sure that Chart Unit is a valid one
	$cval = in_array( $chart_unit , $WDScharts[$chart_type], true);
	
	if ( ! $cval ) {
		if ($DEBUG) {
			dbmsg("ERROR #003 - Invalid Chart Unit Specified [" .
				$chart_unit . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#003", "Invalid Chart Unit", "'" . 
				$chart_unit . "' is not valid" );
			exit;
		}
	} 
	dbmsg("A valid Chart Unit for Chart Type was found");
	
	// Now Check to make sure that Chart Lang is a valid one
	
	if ( empty($chart_lang) ){
		$chart_lang = $WDSLanguages[0];
		dbmsg("No Language selected, using default [" .
			$chart_lang . "]");
	}
	
	dbmsg("Checking for valid Language Setting");
	
	$lval = in_array( $chart_lang , $WDSLanguages, true);	
	
	if ( ! $lval ) {
		if ($DEBUG) {
			dbmsg("ERROR #006 - Invalid Lang Specified [" .
				$chart_lang . "] <b>FATAL ERROR</b>");
			exit;
		} else {
			// Fatal Error
			output_gfx_error ( "#006", "Invalid Lang Specified", "'" . 
				$chart_lang . "' is not valid" );
			exit;
		}
	} 
	
	$SITE['WDSlanguage'] = $chart_lang;		
	dbmsg("Setting Lang Global to [" . $SITE['WDSlanguage'] .
		"]");	

	dbmsg("<b>SUCCESSFULLY COMPLETED CHART and UNITS SELECTION</b>");
		
	// Okay... we got through the selection of the chart and unit and if there
	// is a remote requested, we have that too.  So we now need to get
	// the data from file or Network...

	// get chart data
	if ( empty($REMOTE_CHART) ) {
		dbmsg("REMOTE Not Set, Get Local File");
		$SITE['wdclienthour']	= get_raw($SITE['hloc'] . 
			'clientrawhour.txt',' ', 1);
	} else {
		dbmsg("REMOTE SET, Get Network Copy of File");
		$SITE['wdclienthour']	= get_raw( $REMOTE_CHART,' ', 0 );
	}
	
	// Unless we got an error... we are done with CLI MODE
	// =======================================================================		
}

dbmsg("Setting up Lang using setting");
setLang();

dbmsg('WDSlanguage set to [' . $SITE['WDSlanguage'] . ']');
dbmsg("WDSlanguage values:");
dbmsg(' - WDSdefault_temp_text = ' . $SITE['WDSdefault_temp_text']);
dbmsg(' - WDSdefault_hum_text = ' . $SITE['WDSdefault_hum_text']);
dbmsg(' - WDSdefault_winds_text = ' .$SITE['WDSdefault_winds_text']);
dbmsg(' - WDSdefault_windg_text = ' .$SITE['WDSdefault_windg_text']);
dbmsg(' - WDSdefault_baro_text = ' . $SITE['WDSdefault_baro_text']);
dbmsg(' - WDSdefault_temp_text = ' . $SITE['WDSdefault_temp_text']);
dbmsg(' - WDSdefault_rain_text = ' . $SITE['WDSdefault_rain_text']);

//===========================================================================
// Set Values for various Charts - Use Defaults from on top of script
//===========================================================================

// Set values for Temp
if ($chart_type == 'temp' ) {
    $chart_sval 	= 181;	// DON'T CHANGE
    $chart_eval 	= 240;	// DON'T CHANGE
    $chart_title 	= $SITE['WDSdefault_temp_text'];
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
    if ($chart_unit == "cdeg" ) {
    	$chart_title .= " - C";
    } else {
    	$chart_title .= " - F";
    }
}

if ($chart_type == 'baro' ) {
	$chart_sval		= 301;	// DON'T CHANGE
	$chart_eval		= 360;	// DON'T CHANGE
	$chart_title 	= $SITE['WDSdefault_baro_text'];
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
    if ($chart_unit == "mb" ) {
    	$chart_title .= " - mb";
	}
	if ($chart_unit == "inhg" ) {
		$chart_title .= " - InHg";
	}		
	if ($chart_unit == "kpa" ) {
		$chart_title .= " - kPa";
	}
}

if ($chart_type == 'rain' ) {
	$chart_sval		= 361;	// DON'T CHANGE
	$chart_eval		= 420;	// DON'T CHANGE
	$chart_title 	= $SITE['WDSdefault_rain_text'];
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
    if ($chart_unit == "mm" ) {
		$chart_title .= " - mm";
	} else {
		$chart_title .= " - in";
	}
} 

if ($chart_type == 'winds' ) {
	$chart_sval		= 1;	// DON'T CHANGE
	$chart_eval		= 60;	// DON'T CHANGE
	$chart_title 	= $SITE['WDSdefault_winds_text'];
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
	if ($chart_unit == "kts" ) {
		$chart_title .= " - kts";
	}
	if ($chart_unit == "mph" ) {
		$chart_title .= " - mph";
	}
	if ($chart_unit == "kmh" ) {
		$chart_title .= " - Km/h";
	}
	if ($chart_unit == "ms" ) {
		$chart_title .= " - m/s";
	}
} 

if ($chart_type == 'windg' ) {
	$chart_sval		= 61;	// DON'T CHANGE
	$chart_eval		= 120;	// DON'T CHANGE
	$chart_title 	= $SITE['WDSdefault_windg_text'];
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
	if ($chart_unit == "kts" ) {
		$chart_title .= " - kts";
	}
	if ($chart_unit == "mph" ) {
		$chart_title .= " - mph";
	}
	if ($chart_unit == "kmh" ) {
		$chart_title .= " - Km/h";
	}
	if ($chart_unit == "ms" ) {
		$chart_title .= " - m/s";
	}	
} 

if ($chart_type == 'hum' ) {
	$chart_sval		= 241;	// DON'T CHANGE
	$chart_eval		= 300;	// DON'T CHANGE
	$chart_title 	= $SITE['WDSdefault_hum_text'] . ' %';
    $chart_text 	= $WDSdefault_text_color;
    $chart_line 	= $WDSdefault_line_color;
    $chart_min  	= $WDSdefault_min_color;
    $chart_max  	= $WDSdefault_max_color;
    $chart_backgnd 	= $WDSdefault_backgnd_color;
}

dbmsg("Chart Settings:");
dbmsg(" - chart_type = " . $chart_type );
dbmsg(" - chart_sval = " . $chart_sval );
dbmsg(" - chart_eval = " . $chart_eval );
dbmsg(" - chart_title = " . $chart_title );
dbmsg(" - chart_textcl = ". $chart_text );
dbmsg(" - chart_linecl = " . $chart_line );
dbmsg(" - chart_mincl = " . $chart_min );
dbmsg(" - chart_maxcl = " . $chart_max );
dbmsg(" - chart_backgnd = ". $chart_backgnd );
dbmsg("end of settings");


//#################################################################
// YOU SHOULD NOT NEED TO CHANGE ANYTHING BELOW HERE
//#################################################################

dbmsg("Array of data Collected<pre>"); 
dbmsg(	print_r ( $SITE['wdclienthour'], TRUE ) );
dbmsg("</pre>");

// Collect Y Array data from clientraw hour positions 
// $chart_sval to $chart_eval

$ydata = array();

for ( $idx = $chart_sval ; $idx < $chart_eval + 1  ; $idx ++ ) {
	
	if ($chart_type == 'temp' ) {
		if ($chart_unit == 'cdeg') {
			$ydata[] = $SITE['wdclienthour'][$idx];
		}
		if ($chart_unit == 'fdeg') {
			$ydata[] = TEMPToF ( $SITE['wdclienthour'][$idx] , 1 );
		}
	}
	
	if ($chart_type == 'rain' ) {
		if ($chart_unit == 'mm') {
			$ydata[] = $SITE['wdclienthour'][$idx];
		}
		if ($chart_unit == 'in') {
			$ydata[] = cmToInch ( $SITE['wdclienthour'][$idx] , 2 );
		}
	}
		
	if ($chart_type == 'baro') {
		if ($chart_unit == 'mb') {
			$ydata[] = $SITE['wdclienthour'][$idx];
		}
		if ($chart_unit == 'inhg') {
			$ydata[] = mbToInHg32 ( $SITE['wdclienthour'][$idx] , 2 );
		}
	
		if ($chart_unit == 'kpa' ) {
			$ydata[] = mbTokPa ( $SITE['wdclienthour'][$idx] , 2 );
		}
	}
		
	if ( $chart_type == 'winds' ) {
		if ($chart_unit == 'kts' ) {
			$ydata[] = $SITE['wdclienthour'][$idx];
		}
		if ($chart_unit == 'mph' ) {
			$ydata[] = ktsToMph ( $SITE['wdclienthour'][$idx] , 2 );
		}
		if ($chart_unit == 'kmh' ) {
		$ydata[] = ktsToKmh ( $SITE['wdclienthour'][$idx] , 2 );
		}
		if ($chart_unit == 'ms' ) {
		$ydata[] = ktsToMsec ( $SITE['wdclienthour'][$idx] , 2 );
		}		
	}
				
	if ( $chart_type == 'windg' ) {
		if ($chart_unit == 'kts' ) {
			$ydata[] = $SITE['wdclienthour'][$idx];
		}
		if ($chart_unit == 'mph' ) {
			$ydata[] = ktsToMph ( $SITE['wdclienthour'][$idx] , 2 );
		}
		if ($chart_unit == 'kmh' ) {
			$ydata[] = ktsToKmh ( $SITE['wdclienthour'][$idx] , 2 );
		}
		if ($chart_unit == 'ms' ) {
		$ydata[] = ktsToMsec ( $SITE['wdclienthour'][$idx] , 2 );
		}			
	}
				
	if ( $chart_type == 'hum' ) {
		$ydata[] = $SITE['wdclienthour'][$idx];
	}				
}

// Perform Sparkline Stuff...
$sparkline = new Sparkline_Line();
$sparkline->SetDebugLevel(DEBUG_NONE);

// Create a color called tnetback
$sparkline->setColorHtml("tnetback", $chart_backgnd);
$sparkline->SetColorBackground('tnetback');

// Process the Data We have
$i = 0;
$min  = null;
$max  = null;
$last = null;
while ( list(, $v ) = each( $ydata ) ) {
	$elements = explode(',', $v);
	$value    = @trim($elements[0]);
	$sparkline->SetData($i, $value);
	if (null == $max || $value >= $max[1]) {
		$max = array($i, $value);
	}

	if (null == $min || $value <= $min[1]) {
		$min = array($i, $value);
	}

	$last = array($i, $value);
    $i++;
}

// set y-bound, min and max extent lines

$sparkline->SetYMin($min[1]);
$sparkline->SetPadding(5); 
$sparkline->SetPadding(imagefontheight(FONT_2), 
	imagefontwidth(FONT_2) * strlen(" $last[1]"), 
	0,  
	0);
$sparkline->SetFeaturePoint($min[0],
	$min[1],
	$chart_line,
	5, 
	$min[1], 
	TEXT_TOP, 
	FONT_1 );
$sparkline->SetFeaturePoint($max[0],  
	$max[1],  
	$chart_max, 
	5, 
	$max[1], 
	TEXT_TOP, 
	FONT_1 );
$sparkline->SetFeaturePoint($last[0], 
	$last[1], 
	$chart_min,  
	5, 
	" $last[1]", 
	TEXT_RIGHT,  
	FONT_1 );

$sparkline->SetLineSize(4); 
$sparkline->Render(200, 40);

$sparkline->DrawText(  $chart_title ,
	$sparkline->GetImageWidth() - (imagefontwidth(FONT_1) * 
		strlen($chart_title) + 5),
	$sparkline->GetImageHeight() - imagefontheight(FONT_1),
	$chart_text,
	FONT_1);
	
if ($DEBUG) {
	dbmsg("Image Output suppressed by DEBUG mode");
} else {	
	$sparkline->Output();
}

exit;

##################################################################
// End of Main Script
##################################################################

// dbmsg
// Output Debug Messages in a Consistent format
// Determines if $DEBUG is set and if so,
// outputs the Debug Message with ending matching
// DEBUGLM 1 = <br/>\n  0 = \n only
function dbmsg ($msg){
	global $SITE, $DEBUG, $DEBUGLM;
	
	if ($DEBUGLM) {
		$line_end = "<br/>\n";
	} else {
		$line_end = "\n";
	}
	
	if ($DEBUG) {
		echo "DEBUG: " . $msg . $line_end;
	}
}
##################################################################
// end of script
##################################################################
?>
